@@ -21,9 +21,15 @@
 
 from os import path
 import logging
+
 logger = logging.getLogger('nl')
 here = path.join(path.dirname(__file__))
-hdlr = logging.FileHandler(here + '/clips/log.clp')
+log_file = here + '/clips/log.clp'
+if not path.exists(log_file):
+    lf = open(log_file)
+    lf.write('log file for nl')
+    lf.close()
+hdlr = logging.FileHandler(log_file)
 formatter = logging.Formatter('%(message)s')
 # formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
 hdlr.setFormatter(formatter)
